searchNodes=[{"doc":"The asynchronous version of Elixir's with . async with always executes the right side of each clause inside a new task. Tasks are spawned as soon as all the tasks that it depends on are resolved. In other words, async with resolves the dependency graph and executes all the clauses in the most performant way possible. It also ensures that, if a clause does not match, any running task is shut down. Example defmodule AcmeWeb.PostController do use AcmeWeb , :controller use AsyncWith def show ( conn , %{ &quot;id&quot; =&gt; id } ) do async with { :ok , post } &lt;- Blog . get_post ( id ) , { :ok , author } &lt;- Users . get_user ( post . author_id ) , { :ok , posts_by_the_same_author } &lt;- Blog . get_posts ( author ) , { :ok , similar_posts } &lt;- Blog . get_similar_posts ( post ) , { :ok , comments } &lt;- Blog . list_comments ( post ) , { :ok , comments } &lt;- Blog . preload ( comments , :author ) do conn |&gt; assign ( :post , post ) |&gt; assign ( :author , author ) |&gt; assign ( :posts_by_the_same_author , posts_by_the_same_author ) |&gt; assign ( :similar_posts , similar_posts ) |&gt; assign ( :comments , comments ) |&gt; render ( &quot;show.html&quot; ) end end end Timeout attribute The attribute @async_with_timeout can be used to configure the maximum time allowed to execute all the clauses. It expects a timeout in milliseconds, with the default value of 5000 . defmodule Acme do use AsyncWith @async_with_timeout 1_000 def get_user_info ( user_id ) do async with { :ok , user } &lt;- HTTP . get ( &quot;users/ \#{ user_id } &quot; ) , { :ok , stats } &lt;- HTTP . get ( &quot;users/ \#{ user_id } /stats&quot; ) Map . merge ( user , %{ stats : stats } ) end end end","ref":"AsyncWith.html","title":"AsyncWith","type":"module"},{"doc":"Used to combine matching clauses, executing them asynchronously. async with always executes the right side of each clause inside a new task. Tasks are spawned as soon as all the tasks that it depends on are resolved. In other words, async with resolves the dependency graph and executes all the clauses in the most performant way possible. It also ensures that, if a clause does not match, any running task is shut down. Let's start with an example: iex&gt; opts = %{ width : 10 , height : 15 } iex&gt; async with { :ok , width } &lt;- Map . fetch ( opts , :width ) , ...&gt; { :ok , height } &lt;- Map . fetch ( opts , :height ) do ...&gt; { :ok , width * height } ...&gt; end { :ok , 150 } As in with/1 , if all clauses match, the do block is executed, returning its result. Otherwise the chain is aborted and the non-matched value is returned: iex&gt; opts = %{ width : 10 } iex&gt; async with { :ok , width } &lt;- Map . fetch ( opts , :width ) , ...&gt; { :ok , height } &lt;- Map . fetch ( opts , :height ) do ...&gt; { :ok , width * height } ...&gt; end :error In addition, guards can be used in patterns as well: iex&gt; users = %{ &quot;melany&quot; =&gt; &quot;guest&quot; , &quot;ed&quot; =&gt; :admin } iex&gt; async with { :ok , role } when is_atom ( role ) &lt;- Map . fetch ( users , &quot;ed&quot; ) do ...&gt; :ok ...&gt; end :ok Variables bound inside async with won't leak; &quot;bare expressions&quot; may also be inserted between the clauses: iex&gt; width = nil iex&gt; opts = %{ width : 10 , height : 15 } iex&gt; async with { :ok , width } &lt;- Map . fetch ( opts , :width ) , ...&gt; double_width = width * 2 , ...&gt; { :ok , height } &lt;- Map . fetch ( opts , :height ) do ...&gt; { :ok , double_width * height } ...&gt; end { :ok , 300 } iex&gt; width nil An else option can be given to modify what is being returned from async with in the case of a failed match: iex&gt; opts = %{ width : 10 } iex&gt; async with { :ok , width } &lt;- Map . fetch ( opts , :width ) , ...&gt; { :ok , height } &lt;- Map . fetch ( opts , :height ) do ...&gt; { :ok , width * height } ...&gt; else ...&gt; :error -&gt; ...&gt; { :error , :wrong_data } ...&gt; end { :error , :wrong_data } If an else block is used and there are no matching clauses, an AsyncWith.ClauseError exception is raised. Order-dependent clauses that do not express their dependency via their used or defined variables could lead to race conditions, as they are executed in separated tasks: async with Agent . update ( agent , fn _ -&gt; 1 end ) , Agent . update ( agent , fn _ -&gt; 2 end ) do Agent . get ( agent , fn state -&gt; state end ) # 1 or 2 end","ref":"AsyncWith.html#async/2","title":"AsyncWith.async/2","type":"macro"},{"doc":"","ref":"AsyncWith.ClauseError.html","title":"AsyncWith.ClauseError","type":"exception"}]